@@ -102,7 +102,7 @@ sub readable { &Coro::Handle::FH::readable }
 sub writable { &Coro::Handle::FH::writable }
 
 BEGIN {
-   our $VERSION = '1.1';
+   our $VERSION = '1.2';
 
    require XSLoader;
    XSLoader::load Coro::Mysql::, $VERSION;
@@ -142,7 +142,7 @@ sub unblock {
          $fh = Coro::Handle::unblock ($fh);
       }
 
-      _patch $sock, $DBH->{sockfd}, $fh, tied ${$fh};
+      _patch $sock, $DBH->{sockfd}, $DBH->{mysql_clientversion}, $fh, tied ${$fh};
    }
 
    $DBH
